@@ -1,5 +1,5 @@
 package App::SmokeBrew::Plugin::CPANPLUS::YACSmoke;
-$App::SmokeBrew::Plugin::CPANPLUS::YACSmoke::VERSION = '1.02';
+$App::SmokeBrew::Plugin::CPANPLUS::YACSmoke::VERSION = '1.04';
 #ABSTRACT: A smokebrew plugin for CPANPLUS::YACSmoke based smokers
 
 use strict;
@@ -45,7 +45,7 @@ sub configure {
   $self->builddir->mkpath;
   msg("Fetching '" . $self->_cpanplus . "'", $self->verbose);
   my $loc = 'authors/id/' . $self->_cpanplus;
-  my $fetch = App::SmokeBrew::Tools->fetch( $loc, $self->builddir->absolute, $self->mirrors );
+  my $fetch = App::SmokeBrew::Tools->fetch( $loc, $self->builddir->absolute, [ $self->mirrors ] );
   if ( $fetch ) {
     msg("Fetched to '$fetch'", $self->verbose );
   }
@@ -318,7 +318,7 @@ App::SmokeBrew::Plugin::CPANPLUS::YACSmoke - A smokebrew plugin for CPANPLUS::YA
 
 =head1 VERSION
 
-version 1.02
+version 1.04
 
 =head1 SYNOPSIS
 
